@@ -4,7 +4,7 @@
     begin                : Mon Feb 12 23:45:41 EST 2001
     copyright            : (C) 2001-2003 by Sarang Lakare
     email                : sarang#users.sf.net
-    copyright            : (C) 2003 by Olaf Schmidt
+    copyright            : (C) 2003-2005 by Olaf Schmidt
     email                : ojschmidt@kde.org
  ***************************************************************************/
 
@@ -29,7 +29,8 @@
 #include <qpainter.h>
 #include <qpixmap.h>
 #include <qtimer.h>
-#include <qframe.h>
+#include <qscrollview.h>
+#include <qstringlist.h>
 #include <qrect.h>
 #include <qcursor.h>
 
@@ -39,9 +40,10 @@
 /**
  * The KMagZoomView class provides the view widget for the KmagApp instance.  
  *   
+ * @author Olaf Schmikt <ojschmidt@kde.org>
  * @author Sarang Lakare <sarang#users.sourceforge.net>
  */
-class KMagZoomView : public QFrame
+class KMagZoomView : public QScrollView
 {
   Q_OBJECT
   public:
@@ -79,9 +81,15 @@ class KMagZoomView : public QFrame
     bool getFitToWindow() const { return (m_fitToWindow); };
 
   public slots:
-  
+
     /// Sets zoom to the given value
     void setZoom(float zoom = 0.0);
+
+    /// Sets the rotation to the given value
+    void setRotation(int rotation = 0);
+
+    /// Sets whether the magnified image is shown inverted
+    void setInvertation(bool invert);
     
     /// Grabs a frame from the given portion of the display
     void grabFrame();
@@ -110,6 +118,9 @@ class KMagZoomView : public QFrame
     /// Fits the zoom view to the zoom view window
     void fitToWindow();
 
+  signals:
+    void contextMenu(QPoint pos);
+
   protected:
     /// Called when the widget is hidden
     void hideEvent( QHideEvent * e);
@@ -121,10 +132,7 @@ class KMagZoomView : public QFrame
     void resizeEvent(QResizeEvent *e);
     
     /// Called when the widget is to be repainted
-    void paintEvent(QPaintEvent *p);
-
-    /// This does the actual job of painting.
-    void paintViewImage(QPaintDevice *dev, bool updateMousePos=true);
+    void drawContents ( QPainter * p, int clipx, int clipy, int clipw, int cliph );
 
     /// This function calculates the mouse position relative to the image
     QPoint calcMousePos(bool updateMousePos=true);
@@ -147,6 +155,9 @@ class KMagZoomView : public QFrame
     /// Mouse button release event handler
     void keyReleaseEvent(QKeyEvent *e);
 
+    /// Catch context menu events
+    void contextMenuEvent (QContextMenuEvent *e);
+
     /// Mouse button release event handler
     void focusOutEvent(QFocusEvent *e);
 
@@ -157,9 +168,6 @@ class KMagZoomView : public QFrame
     /// Stores the pixmap grabbed from the screen - to be zoomed
     QPixmap m_grabbedPixmap;
 
-    /// Stores the pixmap which is zoomed from the grabbed one - this will be actaully drawn
-    QPixmap m_grabbedZoomedPixmap;
-
     /// The selected rectangle which is to be grabbed
     KMagSelRect m_selRect;
 
@@ -172,6 +180,9 @@ class KMagZoomView : public QFrame
     /// Zoom matrix
     QWMatrix m_zoomMatrix;
 
+    /// Inverted zoom matrix
+    QWMatrix m_invertedMatrix;
+
     /// Saves the mouse position when a button is clicked and b4 the cursor is moved to new position
     QPoint m_oldMousePos;
 
@@ -222,8 +233,17 @@ class KMagZoomView : public QFrame
     /// Stores the amount to zoom the pixmap
     float m_zoom;
 
+    /// Stores the degrees to rotate the pixmap
+    int m_rotation;
+
+    /// Whether the magnified image is to be shown inverted
+    int m_invert;
+
     /// Fit the zoom view to the zoom window
     bool m_fitToWindow;
+
+    /// Update the magnification matrix
+    void updateMatrix();
 };
 
 #endif // KMagZoomView_h_
